Stan Math Library: stan/math/prim/scal/meta/scalar_type_pre.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

scalar_type_pre.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_SCALAR_TYPE_PRE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_SCALAR_TYPE_PRE_HPP
3
4 #include <stan/math/prim/scal/meta/is_vector.hpp>
5 #include <stan/math/prim/scal/meta/value_type.hpp>
6
7 namespace stan {
8
9 namespace {
10 template <bool is_vec, typename T, typename T_container>
11 struct scalar_type_helper_pre {
12 typedef T_container type;
13 };
14
15 template <typename T, typename T_container>
16 struct scalar_type_helper_pre<true, T, T_container> {
17 typedef typename
18 scalar_type_helper_pre<is_vector<typename stan::math::value_type<T>::type>
19 ::value,
20 typename stan::math::value_type<T>::type,
21 typename
22 stan::math::value_type<T_container>::type>::type
23 type;
24 };
25 }
26
33 template <typename T>
34 struct scalar_type_pre {
35 typedef typename
36 scalar_type_helper_pre<is_vector
37 <typename stan::math::value_type<T>::type>::value,
38 typename stan::math::value_type<T>::type, T>::type
39 type;
40 };
41
42
43 }
44 #endif
45
stan::scalar_type_pre::type
scalar_type_helper_pre< is_vector< typename stan::math::value_type< T >::type >::value, typename stan::math::value_type< T >::type, T >::type type
Definition: scalar_type_pre.hpp:39
stan
Definition: log_sum_exp.hpp:8
is_vector.hpp
stan::is_vector
Definition: is_vector.hpp:10
value_type.hpp
stan::scalar_type_pre
Metaprogram structure to determine the type of first container of the base scalar type of a template ...
Definition: scalar_type_pre.hpp:34
stan::math::value_type
Primary template class for metaprogram to compute the type of values stored in a container.
Definition: value_type.hpp:18

[ Stan Home Page ] © 2011–2016, Stan Development Team.